@@ -16,11 +16,15 @@ def _get_asset_info(asset: Asset, op_type: str) -> Dict:
     if not getattr(asset, f"{op_type}_enabled"):
         return {"enabled": False}
 
-    asset_info = {
-        "enabled": True,
-        "min_amount": getattr(asset, f"{op_type}_min_amount"),
-        "max_amount": getattr(asset, f"{op_type}_max_amount"),
-    }
+    asset_info = {"enabled": True}
+    min_amount_attr = f"{op_type}_min_amount"
+    max_amount_attr = f"{op_type}_max_amount"
+    min_amount = getattr(asset, min_amount_attr)
+    max_amount = getattr(asset, max_amount_attr)
+    if min_amount > Asset._meta.get_field(min_amount_attr).default:
+        asset_info["min_amount"] = min_amount
+    if max_amount < Asset._meta.get_field(max_amount_attr).default:
+        asset_info["max_amount"] = max_amount
     if registered_fee_func is calculate_fee:
         # the anchor has not replaced the default fee function
         # so `fee_fixed` and `fee_percent` are still relevant.
@@ -40,13 +44,7 @@ def info(request):
     See: https://github.com/stellar/stellar-protocol/blob/master/ecosystem/sep-0024.md#info
     """
 
-    info_data = {
-        "deposit": {},
-        "withdraw": {},
-        "fee": {"enabled": True},
-        "transactions": {"enabled": True},
-        "transaction": {"enabled": True},
-    }
+    info_data = {"deposit": {}, "withdraw": {}, "fee": {"enabled": True}}
 
     for asset in Asset.objects.filter(sep24_enabled=True):
         info_data["deposit"][asset.code] = _get_asset_info(asset, "deposit")
