@@ -16,12 +16,14 @@ from polaris.sep24.utils import verify_valid_asset_operation
 from polaris.shared.serializers import TransactionSerializer
 from polaris.integrations import (
     registered_deposit_integration as rdi,
+    registered_withdrawal_integration as rwi,
     registered_scripts_func,
     scripts,
 )
 
 
 logger = getLogger(__name__)
+SEP6_MORE_INFO_PATH = "/sep6/transaction/more_info"
 
 
 def more_info(request: Request, sep6: bool = False) -> Response:
@@ -48,15 +50,20 @@ def more_info(request: Request, sep6: bool = False) -> Response:
         "transaction": request_transaction,
         "asset_code": request_transaction.asset.code,
     }
-    content = rdi.content_for_template(
-        Template.MORE_INFO, transaction=request_transaction
-    )
+    if request_transaction.kind == Transaction.KIND.deposit:
+        content = rdi.content_for_template(
+            Template.MORE_INFO, transaction=request_transaction
+        )
+        if request_transaction.status == Transaction.STATUS.pending_user_transfer_start:
+            context.update(
+                instructions=rdi.instructions_for_pending_deposit(request_transaction)
+            )
+    else:
+        content = rwi.content_for_template(
+            Template.MORE_INFO, transaction=request_transaction
+        )
     if content:
         context.update(content)
-    if request_transaction.status == Transaction.STATUS.pending_user_transfer_start:
-        context.update(
-            instructions=rdi.instructions_for_pending_deposit(request_transaction)
-        )
 
     if registered_scripts_func is not scripts:
         logger.warning(
@@ -67,14 +74,17 @@ def more_info(request: Request, sep6: bool = False) -> Response:
         )
     context["scripts"] = registered_scripts_func(content)
 
+    # more_info.html will update the 'callback' parameter value to 'success' after
+    # making the callback. If the page is then reloaded, the callback is not included
+    # in the rendering context, ensuring only one successful callback request is made.
     callback = request.GET.get("callback")
-    if callback:
+    if callback and callback != "success":
         context["callback"] = callback
 
     return Response(context, template_name="polaris/more_info.html")
 
 
-def transactions(request: Request, account: str, sep6: bool = False) -> Response:
+def transactions(request: Request, account: str, sep6: bool = False,) -> Response:
     try:
         limit = _validate_limit(request.GET.get("limit"))
     except ValueError:
@@ -126,10 +136,10 @@ def transactions(request: Request, account: str, sep6: bool = False) -> Response
     return Response({"transactions": serializer.data})
 
 
-def transaction(request: Request, account: str, sep6: bool = False) -> Response:
+def transaction(request: Request, account: str, sep6: bool = False,) -> Response:
     try:
         request_transaction = _get_transaction_from_request(
-            request, account=account, sep6=sep6
+            request, account=account, sep6=sep6,
         )
     except (AttributeError, ValidationError) as exc:
         return render_error_response(str(exc), status_code=status.HTTP_400_BAD_REQUEST)
@@ -221,7 +231,9 @@ def _compute_qset_filters(req_params, translation_dict):
     }
 
 
-def _get_transaction_from_request(request, account: str = None, sep6: bool = False):
+def _get_transaction_from_request(
+    request, account: str = None, sep6: bool = False,
+):
     translation_dict = {
         "id": "id",
         "stellar_transaction_id": "stellar_transaction_id",
